Module executor

Module executor 

Callback executor for processing subscriber callbacks

This module provides a simple callback queue that allows subscribers to enqueue callbacks for later processing by the node’s spin methods.

Structs

CallbackExecutor
A simple executor that queues callbacks for later processing

Type Aliases

Callback
A callback that can be executed by the executor