pub struct CallbackExecutor { /* private fields */ }Expand description
A simple executor that queues callbacks for later processing
The executor provides a thread-safe way to enqueue callbacks from subscriber threads and process them in the node’s spin loop.
Implementations
Sourceimpl CallbackExecutor
impl CallbackExecutor
Sourcepub fn enqueue(&self, callback: Callback)
pub fn enqueue(&self, callback: Callback)
Enqueues a callback for later processing
This method is thread-safe and can be called from subscriber callbacks.
Sourcepub fn process_pending(&self) -> usize
pub fn process_pending(&self) -> usize
Processes all pending callbacks
Returns the number of callbacks that were processed.
Sourcepub fn pending_count(&self) -> usize
pub fn pending_count(&self) -> usize
Returns the number of pending callbacks
Sourcepub fn notified(&self) -> Notified<'_>
pub fn notified(&self) -> Notified<'_>
Returns a future that resolves when a callback is enqueued or shutdown is signaled. Must be called (to register interest) before draining the queue.
Sourcepub fn shutdown(&self)
pub fn shutdown(&self)
Signals the executor to shutdown
After shutdown, no new callbacks will be accepted.
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Returns true if the executor has been shutdown