pub struct Time {
pub sec: u64,
pub nsec: u32,
}Expand description
Time representation for Zenobuf
This struct represents a point in time, similar to the Time message in ROS.
Fields
sec: u64Seconds since the Unix epoch
nsec: u32Nanoseconds since the last second
Implementations
Sourceimpl Time
impl Time
Sourcepub fn from_duration(duration: Duration) -> Self
pub fn from_duration(duration: Duration) -> Self
Creates a Time from a Duration since the Unix epoch
Sourcepub fn to_duration(&self) -> Duration
pub fn to_duration(&self) -> Duration
Converts the Time to a Duration since the Unix epoch